@@ -5,6 +5,10 @@ from typing import ClassVar, Dict
 from dbt.adapters.base.column import Column
 from dbt.exceptions import DbtRuntimeError
 
+# Taken from the MAX_LENGTH variable in
+# https://github.com/trinodb/trino/blob/master/core/trino-spi/src/main/java/io/trino/spi/type/VarcharType.java
+TRINO_VARCHAR_MAX_LENGTH = 2147483646
+
 
 @dataclass
 class TrinoColumn(Column):
@@ -15,15 +19,32 @@ class TrinoColumn(Column):
         "INTEGER": "INT",
     }
 
+    @property
+    def data_type(self):
+        # when varchar has no defined size, default to unbound varchar
+        # the super().data_type defaults to varchar(256)
+        if self.dtype.lower() == "varchar" and self.char_size is None:
+            return self.dtype
+
+        return super().data_type
+
     @classmethod
     def string_type(cls, size: int) -> str:
         return "varchar({})".format(size)
 
+    def string_size(self) -> int:
+        # override the string_size function to handle the unbound varchar case
+        if self.dtype.lower() == "varchar" and self.char_size is None:
+            return TRINO_VARCHAR_MAX_LENGTH
+
+        return super().string_size()
+
     @classmethod
     def from_description(cls, name: str, raw_data_type: str) -> "Column":
-        # some of the Trino data types specify a type and not a precision
-        if raw_data_type.startswith(("array", "map", "row")):
+        # Most of the Trino data types specify a type and not a precision/scale/charsize
+        if not raw_data_type.lower().startswith(("varchar", "char", "decimal")):
             return cls(name, raw_data_type)
+        # Trino data types that do specify a precision/scale/charsize:
         match = re.match(
             r"(?P<type>[^(]+)(?P<size>\([^)]+\))?(?P<type_suffix>[\w ]+)?", raw_data_type
         )
